pilot.filemanagement.webhdfs_adaptor.WebHDFSFileAdaptor

Package pilot :: Package filemanagement :: Module webhdfs_adaptor :: Class WebHDFSFileAdaptor |

# Class WebHDFSFileAdaptor

source code

Instance Methods
__init__(self, service_url) x.__init__(...) initializes x; see help(type(x)) for signature | source code
get_security_context(self) Returns security context that needs to be available on the distributed node in order to access this Pilot Data | source code
initialize_pilotstore(self) | source code
get_pilotstore_size(self) | source code
delete_pilotstore(self) | source code
get_state(self) | source code
create_pd(self, pd_id) | source code
put_pd(self, pd) | source code
copy_pd_to_url(self, pd, local_url, remote_url) | source code
copy_pd(self, pd, ps_new) | source code
get_pd(self, pd, target_url) | source code
remove_pd(self, pd) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| HDFS_USER_NAME = `"luckow"`
| HDFS_SERVICE_HOST = `"192.168.2.108"`
| HDFS_SERVICE_PORT = `50070`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, service_url) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)